@@ -182,6 +182,8 @@ PyAPI_FUNC(int) PyDict_DelItemString(PyObject *arg0, const char *arg1);
 PyAPI_FUNC(PyObject *) PyDict_GetItem(PyObject *arg0, PyObject *arg1);
 #define PyDict_GetItemString PyPyDict_GetItemString
 PyAPI_FUNC(PyObject *) PyDict_GetItemString(PyObject *arg0, const char *arg1);
+#define PyDict_GetItemWithError PyPyDict_GetItemWithError
+PyAPI_FUNC(PyObject *) PyDict_GetItemWithError(PyObject *arg0, PyObject *arg1);
 #define PyDict_Items PyPyDict_Items
 PyAPI_FUNC(PyObject *) PyDict_Items(PyObject *arg0);
 #define PyDict_Keys PyPyDict_Keys
@@ -326,6 +328,8 @@ PyAPI_FUNC(int) PyFunction_Check(void * arg0);
 PyAPI_FUNC(int) PyFunction_CheckExact(void * arg0);
 #define PyFunction_GetCode PyPyFunction_GetCode
 PyAPI_FUNC(PyObject *) PyFunction_GetCode(PyObject *arg0);
+#define PyGILState_Check PyPyGILState_Check
+PyAPI_FUNC(int) PyGILState_Check(void);
 #define PyGILState_Ensure PyPyGILState_Ensure
 PyAPI_FUNC(int) PyGILState_Ensure(void);
 #define PyGILState_Release PyPyGILState_Release
@@ -806,6 +810,10 @@ PyAPI_FUNC(PyObject *) PyUnicode_AsEncodedObject(PyObject *arg0, const char *arg
 PyAPI_FUNC(PyObject *) PyUnicode_AsEncodedString(PyObject *arg0, const char *arg1, const char *arg2);
 #define PyUnicode_AsLatin1String PyPyUnicode_AsLatin1String
 PyAPI_FUNC(PyObject *) PyUnicode_AsLatin1String(PyObject *arg0);
+#define PyUnicode_AsUCS4 PyPyUnicode_AsUCS4
+PyAPI_FUNC(Py_UCS4 *) PyUnicode_AsUCS4(PyObject * arg0, Py_UCS4 * arg1, Py_ssize_t arg2, int arg3);
+#define PyUnicode_AsUCS4Copy PyPyUnicode_AsUCS4Copy
+PyAPI_FUNC(Py_UCS4 *) PyUnicode_AsUCS4Copy(PyObject * arg0);
 #define PyUnicode_AsUTF16String PyPyUnicode_AsUTF16String
 PyAPI_FUNC(PyObject *) PyUnicode_AsUTF16String(PyObject *arg0);
 #define PyUnicode_AsUTF32String PyPyUnicode_AsUTF32String
@@ -1004,10 +1012,14 @@ PyAPI_FUNC(int) _PyComplex_AsCComplex(PyObject *arg0, struct Py_complex_t *arg1)
 PyAPI_FUNC(PyObject *) _PyComplex_FromCComplex(struct Py_complex_t *arg0);
 #define _PyDateTime_FromDateAndTime _PyPyDateTime_FromDateAndTime
 PyAPI_FUNC(PyObject *) _PyDateTime_FromDateAndTime(int arg0, int arg1, int arg2, int arg3, int arg4, int arg5, int arg6, PyObject *arg7, PyTypeObject *arg8);
+#define _PyDateTime_FromTimestamp _PyPyDateTime_FromTimestamp
+PyAPI_FUNC(PyObject *) _PyDateTime_FromTimestamp(PyObject *arg0, PyObject *arg1, PyObject *arg2);
 #define _PyDateTime_Import _PyPyDateTime_Import
 PyAPI_FUNC(PyDateTime_CAPI *) _PyDateTime_Import(void);
 #define _PyDate_FromDate _PyPyDate_FromDate
 PyAPI_FUNC(PyObject *) _PyDate_FromDate(int arg0, int arg1, int arg2, PyTypeObject *arg3);
+#define _PyDate_FromTimestamp _PyPyDate_FromTimestamp
+PyAPI_FUNC(PyObject *) _PyDate_FromTimestamp(PyObject *arg0, PyObject *arg1);
 #define _PyDelta_FromDelta _PyPyDelta_FromDelta
 PyAPI_FUNC(PyObject *) _PyDelta_FromDelta(int arg0, int arg1, int arg2, int arg3, PyTypeObject *arg4);
 #define _PyDict_HasOnlyStringKeys _PyPyDict_HasOnlyStringKeys
